######################################################################
#
#   CentOS - Branding design models
#
#   This file provides configuration options for tcar-render(1)
#   command to produce The CentOS Brand in different colors, formats,
#   and heights from design models provided by The CentOS Artwork SIG
#   in scalable vector graphic format.
#
#   The CentOS Brand is the main visual manifestation of The CentOS
#   Project.
#
#   Example 1. Directory structure
#   ------------------------------------------------------------------
#   .
#   |-- Final/
#   |   `-- ${IMAGE_BACKGROUND_COLOR}/
#   |       `-- ${IMAGE_FOREGROUND_COLOR}/
#   |           `-- ${IMAGE_HEIGHT}/
#   |               `-- ${IMAGE_NAME}.${IMAGE_FORMAT}
#   |-- ${PADDING}
#   |   `-- ${HEIGHT}
#   `-- render.conf
#   ------------------------------------------------------------------
#
#   In Example 1. "Directory structure", PADDING represents the
#   protection area used in design models. This is, the empty space
#   between the image and its boundaries. The PADDING variable can
#   take one of the values described in Table 1.  "Naming conventions
#   for padding directory".
#
#   In Example 1. "Directory structure", HEIGHT is a numerical value
#   and identifies the height used in design models. You can use this
#   value to append final images produced from the same height
#   information and produce new images from them.
#
#   In Example 1. "Directory structure", the render.conf file contains
#   the configuration options used to produce The CentOS Brand in
#   different image formats, colors, and heights. This is the
#   information tcar-render(1) command uses to get into production.
#
#   Example 2. Naming convention for padding directory
#   ------------------------------------------------------------------
#   Name    Description
#   ------------------------------------------------------------------
#   0000    The final image is produced with no padding.
#
#   1111    The final image is produced with the same padding on all
#           its sides. Here, the padding value can be anything greater
#           than 0.
#
#   0101    The final image is produced with no padding on top and
#           bottom but it uses padding on left and right sides. Here,
#           the top and bottom padding have both the same value.
#
#   2120    The final image is produced with no padding on the left
#           side but uses padding on the top, right and bottom sides.
#           Here, the top padding is two times bigger than the right
#           padding value.  Here, both top and bottom padding have
#           both the same value.
#
#   2121    The final image is produced with padding on all its sides.
#           Here, the top padding is two times bigger than the right
#           padding value, as well as the bottom padding is two times
#           bigger than the left padding value. In all cases both the
#           top padding and the bottom padding have both the same
#           value. Likewise, the right padding and left padding have
#           both the same value. 
#
#   TRBL    T=top, R=right, B=bottom, L=left
#   ------------------------------------------------------------------
#
#   The CentOS Artwork SIG provides The CentOS Brand design models in
#   specific heights because they are required in that way by
#   centos-logos (and maybe other) package.
#
#   In case you need to render PNG images from design models that
#   don't exist in this directory, you can create the related design
#   model and request its inclusion here, or you can combine each
#   design model The CentOS Brand is made of to achieve a result which
#   cannot be built from design models currently available in the
#   repository (e.g., you can append the centos-symbol.svg,
#   centos-type.svg and wiki.svg design models to create The CentOS
#   Wiki Logo.) 
#
#   You can use The CentOS Brand design models provided here as source
#   to render them in different sizes, formats, colors and heights.
#   Nevertheless, you must not use The CentOS Brand provided here in
#   any form to imply your product is part of The CentOS Project
#   without The CentOS Project authorization.
#
#   For more information about how to write configuration files for
#   tcar-render(1) command, see the tcar-render.conf(5) man page.
#
######################################################################

#=====================================================================
# 1. Build images used to brand final images (The CentOS Brand)
#=====================================================================

[centos-logo.png]
render-type = "image"
render-from = "${TCAR_BASEDIR}/Models/Branding/2121/168/centos-logo.svg"
render-flow = "extended"
render-as   = "xpm pdf jpg tif"
heights     = "16 20 22 24 32 36 38 40 48 64 72 78 96 112 124 128 148 164 196 200 256 512"
fgcolors    = "000000 ffffff ad7fa8 75507b 5c3566 729fcf 3465a4 204a87 fce94f edd400 c4a000 8ae234 73d216 4e9a06 fcaf3e f57900 ce5c00 e9b96e c17d11 8f5902 ef2929 cc0000 a40000 eeeeec d3d7cf babdb6 888a85 555753 2e3436"
bgcolors    = "ffffff-0"
command     = "/usr/bin/convert"

[centos-symbol.png]
render-type = "image"
render-from = "${TCAR_BASEDIR}/Models/Branding/2121/168/centos-symbol.svg"
render-flow = "extended"
render-as   = "xpm pdf jpg tif"
heights     = "16 20 22 24 32 36 38 40 48 64 72 78 96 112 124 128 148 164 196 200 256 512"
fgcolors    = "ffffff"
bgcolors    = "ffffff-0"
command     = "/usr/bin/convert"

#=====================================================================
# 2. Build images needed to produce other images.
#=====================================================================

#=====================================================================
# 3. Build final images.
#=====================================================================

#=====================================================================
# 4. Build final tar.gz.
#=====================================================================
